#!/usr/bin/env node

var argv = require('optimist').argv;
var minifier = require('uglify-js');
var filendir = require('filendir');
var glob = require('glob');
var path = require('path');
var readline = require('readline');

var rl = readline.createInterface({
    input: process.stdin,
    output: process.stdout
});

var src;
var dest;
var combine;
var compiledCode = '';

if (argv.help) {
    console.log([
        'usage: jscompiler [options]',
        '',
        'options:',
        '  -src         set source path',
        '  -dest        set destination path',
        '  -help        help',
        '  -c           combine files into one'
    ].join('\n'));
    process.exit();
}

src = argv.src;
dest = argv.dest;
combine = argv.c;

if (!src) {
    rl.question('Please provide input path: ', function (src) {
        if (!dest) {
            rl.question('Please provide output path: ', function (dest) {
                compile(src, dest);
            });
        }
    })
} else if(!dest) {
    rl.question('Please provide output path: ', function (dest) {
        compile(src, dest);
    });
} else {
    compile(src, dest);
}

function compile(src, dest) {
    glob(src, function (er, files) {
        files.forEach(function(file) {
            var filePath = path.join(dest, path.basename(file));
            var result = minifier.minify(file);

            if (combine) {
                compiledCode += result.code;
            } else {
                filendir.writeFileSync(filePath, result.code);
            }
        });

        if (combine) {
            var filePath = path.join(dest, 'main.js');

            filendir.writeFileSync(filePath, compiledCode);
        }

        rl.close();
    });
}
